"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import artifact.artifact.v1alpha.artifact_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GetFileCatalogRequest(google.protobuf.message.Message):
    """GetFileCatalogRequest"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    CATALOG_ID_FIELD_NUMBER: builtins.int
    FILE_ID_FIELD_NUMBER: builtins.int
    FILE_UID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """id of the namespace"""
    catalog_id: builtins.str
    """id of the catalog"""
    file_id: builtins.str
    """id of the file(i.e. file name)"""
    file_uid: builtins.str
    """Uid of the file"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        catalog_id: builtins.str = ...,
        file_id: builtins.str = ...,
        file_uid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["catalog_id", b"catalog_id", "file_id", b"file_id", "file_uid", b"file_uid", "namespace_id", b"namespace_id"]) -> None: ...

global___GetFileCatalogRequest = GetFileCatalogRequest

@typing_extensions.final
class GetFileCatalogResponse(google.protobuf.message.Message):
    """GetFileCatalogResponse"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ChunkType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ChunkTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[GetFileCatalogResponse._ChunkType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CHUNK_TYPE_UNSPECIFIED: GetFileCatalogResponse._ChunkType.ValueType  # 0
        """unspecified"""
        CHUNK_TYPE_TEXT: GetFileCatalogResponse._ChunkType.ValueType  # 1
        """text"""
        CHUNK_TYPE_IMAGE: GetFileCatalogResponse._ChunkType.ValueType  # 2
        """image"""
        CHUNK_TYPE_AUDIO: GetFileCatalogResponse._ChunkType.ValueType  # 3
        """audio"""
        CHUNK_TYPE_VIDEO: GetFileCatalogResponse._ChunkType.ValueType  # 4
        """video"""

    class ChunkType(_ChunkType, metaclass=_ChunkTypeEnumTypeWrapper):
        """chunk type"""

    CHUNK_TYPE_UNSPECIFIED: GetFileCatalogResponse.ChunkType.ValueType  # 0
    """unspecified"""
    CHUNK_TYPE_TEXT: GetFileCatalogResponse.ChunkType.ValueType  # 1
    """text"""
    CHUNK_TYPE_IMAGE: GetFileCatalogResponse.ChunkType.ValueType  # 2
    """image"""
    CHUNK_TYPE_AUDIO: GetFileCatalogResponse.ChunkType.ValueType  # 3
    """audio"""
    CHUNK_TYPE_VIDEO: GetFileCatalogResponse.ChunkType.ValueType  # 4
    """video"""

    @typing_extensions.final
    class Metadata(google.protobuf.message.Message):
        """metadata"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FILE_UID_FIELD_NUMBER: builtins.int
        FILE_ID_FIELD_NUMBER: builtins.int
        FILE_TYPE_FIELD_NUMBER: builtins.int
        FILE_SIZE_FIELD_NUMBER: builtins.int
        FILE_UPLOAD_TIME_FIELD_NUMBER: builtins.int
        FILE_PROCESS_STATUS_FIELD_NUMBER: builtins.int
        file_uid: builtins.str
        """file uid"""
        file_id: builtins.str
        """file id"""
        file_type: artifact.artifact.v1alpha.artifact_pb2.FileType.ValueType
        """file type"""
        file_size: builtins.int
        """file size in bytes"""
        @property
        def file_upload_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
            """upload time"""
        file_process_status: artifact.artifact.v1alpha.artifact_pb2.FileProcessStatus.ValueType
        """file process status"""
        def __init__(
            self,
            *,
            file_uid: builtins.str = ...,
            file_id: builtins.str = ...,
            file_type: artifact.artifact.v1alpha.artifact_pb2.FileType.ValueType = ...,
            file_size: builtins.int = ...,
            file_upload_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
            file_process_status: artifact.artifact.v1alpha.artifact_pb2.FileProcessStatus.ValueType = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["file_upload_time", b"file_upload_time"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["file_id", b"file_id", "file_process_status", b"file_process_status", "file_size", b"file_size", "file_type", b"file_type", "file_uid", b"file_uid", "file_upload_time", b"file_upload_time"]) -> None: ...

    @typing_extensions.final
    class Text(google.protobuf.message.Message):
        """text message"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PIPELINE_IDS_FIELD_NUMBER: builtins.int
        TRANSFORMED_CONTENT_FIELD_NUMBER: builtins.int
        TRANSFORMED_CONTENT_CHUNK_NUM_FIELD_NUMBER: builtins.int
        TRANSFORMED_CONTENT_TOKEN_NUM_FIELD_NUMBER: builtins.int
        TRANSFORMED_CONTENT_UPDATE_TIME_FIELD_NUMBER: builtins.int
        @property
        def pipeline_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """pipelines"""
        transformed_content: builtins.str
        """transformed content"""
        transformed_content_chunk_num: builtins.int
        """transformed content chunk number"""
        transformed_content_token_num: builtins.int
        """transformed content token number"""
        @property
        def transformed_content_update_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
            """transformed content update time"""
        def __init__(
            self,
            *,
            pipeline_ids: collections.abc.Iterable[builtins.str] | None = ...,
            transformed_content: builtins.str = ...,
            transformed_content_chunk_num: builtins.int = ...,
            transformed_content_token_num: builtins.int = ...,
            transformed_content_update_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["transformed_content_update_time", b"transformed_content_update_time"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["pipeline_ids", b"pipeline_ids", "transformed_content", b"transformed_content", "transformed_content_chunk_num", b"transformed_content_chunk_num", "transformed_content_token_num", b"transformed_content_token_num", "transformed_content_update_time", b"transformed_content_update_time"]) -> None: ...

    @typing_extensions.final
    class Chunk(google.protobuf.message.Message):
        """chunk message"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        UID_FIELD_NUMBER: builtins.int
        TYPE_FIELD_NUMBER: builtins.int
        START_POS_FIELD_NUMBER: builtins.int
        END_POS_FIELD_NUMBER: builtins.int
        CONTENT_FIELD_NUMBER: builtins.int
        TOKENS_NUM_FIELD_NUMBER: builtins.int
        EMBEDDING_FIELD_NUMBER: builtins.int
        CREATE_TIME_FIELD_NUMBER: builtins.int
        RETRIEVABLE_FIELD_NUMBER: builtins.int
        uid: builtins.str
        """chunk uid"""
        type: global___GetFileCatalogResponse.ChunkType.ValueType
        """chunk type. i.e. text, image, audio, and video"""
        start_pos: builtins.int
        """chunk start position"""
        end_pos: builtins.int
        """chunk end position"""
        content: builtins.str
        """chunk content"""
        tokens_num: builtins.int
        """chunk tokens num"""
        @property
        def embedding(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
            """embedding. float32 array"""
        @property
        def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
            """chunk create time"""
        retrievable: builtins.bool
        """chunk retrievable"""
        def __init__(
            self,
            *,
            uid: builtins.str = ...,
            type: global___GetFileCatalogResponse.ChunkType.ValueType = ...,
            start_pos: builtins.int = ...,
            end_pos: builtins.int = ...,
            content: builtins.str = ...,
            tokens_num: builtins.int = ...,
            embedding: collections.abc.Iterable[builtins.float] | None = ...,
            create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
            retrievable: builtins.bool = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["create_time", b"create_time"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "create_time", b"create_time", "embedding", b"embedding", "end_pos", b"end_pos", "retrievable", b"retrievable", "start_pos", b"start_pos", "tokens_num", b"tokens_num", "type", b"type", "uid", b"uid"]) -> None: ...

    ORIGINAL_DATA_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    CHUNKS_FIELD_NUMBER: builtins.int
    original_data: builtins.str
    """original data is encoded in base64"""
    @property
    def metadata(self) -> global___GetFileCatalogResponse.Metadata:
        """file catalog"""
    @property
    def text(self) -> global___GetFileCatalogResponse.Text:
        """text"""
    @property
    def chunks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetFileCatalogResponse.Chunk]:
        """chunks"""
    def __init__(
        self,
        *,
        original_data: builtins.str = ...,
        metadata: global___GetFileCatalogResponse.Metadata | None = ...,
        text: global___GetFileCatalogResponse.Text | None = ...,
        chunks: collections.abc.Iterable[global___GetFileCatalogResponse.Chunk] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "text", b"text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chunks", b"chunks", "metadata", b"metadata", "original_data", b"original_data", "text", b"text"]) -> None: ...

global___GetFileCatalogResponse = GetFileCatalogResponse



# pylint: disable=no-member,wrong-import-position,too-many-lines,no-name-in-module
from datetime import datetime
from typing import Callable, List, Optional

from google.protobuf import field_mask_pb2, timestamp_pb2
from google.protobuf.struct_pb2 import Struct

import instill.protogen.common.healthcheck.v1beta.healthcheck_pb2 as healthcheck
import instill.protogen.common.task.v1alpha.task_pb2 as task_interface
import instill.protogen.model.model.v1alpha.model_definition_pb2 as model_definition_interface

# model
import instill.protogen.model.model.v1alpha.model_pb2 as model_interface
import instill.protogen.model.model.v1alpha.model_public_service_pb2_grpc as model_service
from instill.clients.base import Client, RequestFactory
from instill.clients.instance import InstillInstance
from instill.helpers.const import HOST_URL_PROD
from instill.utils.error_handler import grpc_handler


class ModelClient(Client):
    def __init__(
        self,
        api_token: str,
        lookup_func: Callable[[str], str],
        url: str = HOST_URL_PROD,
        secure: bool = True,
        requester_id: str = "",
        async_enabled: bool = False,
    ) -> None:
        self.host: InstillInstance = InstillInstance(
            model_service.ModelPublicServiceStub,
            url=url,
            token=api_token,
            secure=secure,
            async_enabled=async_enabled,
        )
        self.metadata = []

        if requester_id != "":
            requester_uid = lookup_func(requester_id)
            self.metadata = [("instill-requester-uid", requester_uid)]

    def close(self):
        if self.is_serving():
            self.host.channel.close()

    async def async_close(self):
        if self.is_serving():
            self.host.channel.close()

    @property
    def host(self):
        return self._host

    @host.setter
    def host(self, host: InstillInstance):
        self._host = host

    @property
    def instance(self):
        return self._instance

    @instance.setter
    def instance(self, instance: str):
        self._instance = instance

    def set_instance(self, instance: str):
        self._instance = instance

    @property
    def metadata(self):
        return self._metadata

    @metadata.setter
    def metadata(self, metadata: List[tuple]):
        self._metadata = metadata

    def liveness(self, async_enabled: bool = False) -> model_interface.LivenessResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.Liveness,
                request=model_interface.LivenessRequest(),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.Liveness,
            request=model_interface.LivenessRequest(),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    def readiness(
        self, async_enabled: bool = False
    ) -> model_interface.ReadinessResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.Readiness,
                request=model_interface.ReadinessRequest(),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.Readiness,
            request=model_interface.ReadinessRequest(),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    def is_serving(self) -> bool:
        try:
            return (
                self.readiness().health_check_response.status
                == healthcheck.HealthCheckResponse.SERVING_STATUS_SERVING
            )
        except Exception:
            return False

    @grpc_handler
    def watch_model(
        self,
        namespace_id: str,
        model_id: str,
        version: str,
        async_enabled: bool = False,
    ) -> model_interface.WatchNamespaceModelResponse:

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.WatchNamespaceModel,
                request=model_interface.WatchNamespaceModelRequest(
                    namespace_id=namespace_id,
                    model_id=model_id,
                    version=version,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.WatchNamespaceModel,
            request=model_interface.WatchNamespaceModelRequest(
                namespace_id=namespace_id,
                model_id=model_id,
                version=version,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def watch_latest_model(
        self,
        namespace_id: str,
        model_id: str,
        async_enabled: bool = False,
    ) -> model_interface.WatchNamespaceLatestModelResponse:

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.WatchNamespaceLatestModel,
                request=model_interface.WatchNamespaceLatestModelRequest(
                    namespace_id=namespace_id,
                    model_id=model_id,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.WatchNamespaceLatestModel,
            request=model_interface.WatchNamespaceLatestModelRequest(
                namespace_id=namespace_id,
                model_id=model_id,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def create_model(
        self,
        namespace_id: str,
        model_id: str,
        task: task_interface.Task.ValueType,
        region: str,
        hardware: str,
        definition: str = "model-definitions/container",
        configuration: Optional[dict] = None,
        is_public: bool = True,
        async_enabled: bool = False,
    ) -> model_interface.CreateNamespaceModelResponse:

        model = model_interface.Model()
        model.id = model_id
        model.task = task
        model.region = region
        model.hardware = hardware
        model.model_definition = definition
        model.visibility = (
            model_interface.Model.VISIBILITY_PUBLIC
            if is_public
            else model_interface.Model.VISIBILITY_PRIVATE
        )

        configuration = {} if configuration is None else configuration
        model.configuration.Clear()
        model.configuration.update(configuration)
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.CreateNamespaceModel,
                request=model_interface.CreateNamespaceModelRequest(
                    namespace_id=namespace_id,
                    model=model,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.CreateNamespaceModel,
            request=model_interface.CreateNamespaceModelRequest(
                namespace_id=namespace_id,
                model=model,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def trigger(
        self,
        namespace_id: str,
        model_id: str,
        task_inputs: List[dict],
        version: str,
        async_enabled: bool = False,
    ) -> model_interface.TriggerNamespaceModelResponse:

        request = model_interface.TriggerNamespaceModelRequest(
            namespace_id=namespace_id,
            model_id=model_id,
            version=version,
        )
        for input_value in task_inputs:
            trigger_inputs = Struct()
            trigger_inputs.update(input_value)
            request.task_inputs.append(trigger_inputs)

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.TriggerNamespaceModel,
                request=request,
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.TriggerNamespaceModel,
            request=request,
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def trigger_async(
        self,
        namespace_id: str,
        model_id: str,
        task_inputs: List[dict],
        version: str,
        async_enabled: bool = False,
    ) -> model_interface.TriggerAsyncNamespaceModelResponse:

        request = model_interface.TriggerAsyncNamespaceModelRequest(
            namespace_id=namespace_id,
            model_id=model_id,
            version=version,
        )
        for input_value in task_inputs:
            trigger_inputs = Struct()
            trigger_inputs.update(input_value)
            request.task_inputs.append(trigger_inputs)

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.TriggerAsyncNamespaceModel,
                request=request,
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.TriggerAsyncNamespaceModel,
            request=request,
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def trigger_latest(
        self,
        namespace_id: str,
        model_id: str,
        task_inputs: List[dict],
        async_enabled: bool = False,
    ) -> model_interface.TriggerNamespaceLatestModelResponse:

        request = model_interface.TriggerNamespaceLatestModelRequest(
            namespace_id=namespace_id,
            model_id=model_id,
        )
        for input_value in task_inputs:
            trigger_input = Struct()
            trigger_input.update(input_value)
            request.task_inputs.append(trigger_input)

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.TriggerNamespaceLatestModel,
                request=request,
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.TriggerNamespaceLatestModel,
            request=request,
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def trigger_async_latest(
        self,
        namespace_id: str,
        model_id: str,
        task_inputs: List[dict],
        async_enabled: bool = False,
    ) -> model_interface.TriggerAsyncNamespaceLatestModelResponse:

        request = model_interface.TriggerAsyncNamespaceLatestModelRequest(
            namespace_id=namespace_id,
            model_id=model_id,
        )
        for input_value in task_inputs:
            trigger_inputs = Struct()
            trigger_inputs.update(input_value)
            request.task_inputs.append(trigger_inputs)

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.TriggerAsyncNamespaceLatestModel,
                request=request,
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.TriggerAsyncNamespaceLatestModel,
            request=request,
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def trigger_model_binary_file_upload(
        self,
        namespace_id: str,
        model_id: str,
        task_inputs: List[dict],
        version: str,
        async_enabled: bool = False,
    ) -> model_interface.TriggerNamespaceModelBinaryFileUploadResponse:

        request = model_interface.TriggerNamespaceModelBinaryFileUploadRequest(
            namespace_id=namespace_id,
            model_id=model_id,
            version=version,
        )
        for input_value in task_inputs:
            trigger_inputs = Struct()
            trigger_inputs.update(input_value)
            request.task_input.append(trigger_inputs)

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.TriggerNamespaceModelBinaryFileUpload,
                request=request,
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.TriggerNamespaceModelBinaryFileUpload,
            request=request,
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def trigger_latest_model_binary_file_upload(
        self,
        namespace_id: str,
        model_id: str,
        task_input: List[dict],
        async_enabled: bool = False,
    ) -> model_interface.TriggerNamespaceLatestModelBinaryFileUploadResponse:

        request = model_interface.TriggerNamespaceLatestModelBinaryFileUploadRequest(
            namespace_id=namespace_id,
            model_id=model_id,
        )
        for input_value in task_input:
            trigger_inputs = Struct()
            trigger_inputs.update(input_value)
            request.task_input.append(trigger_inputs)

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.TriggerNamespaceLatestModelBinaryFileUpload,
                request=request,
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.TriggerNamespaceLatestModelBinaryFileUpload,
            request=request,
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def get_namespace_model_operation(
        self,
        namespace_id: str,
        model_id: str,
        version: str,
        async_enabled: bool = False,
    ) -> model_interface.GetNamespaceModelOperationResponse:

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.GetNamespaceModelOperation,
                request=model_interface.GetNamespaceModelOperationRequest(
                    namespace_id=namespace_id,
                    model_id=model_id,
                    version=version,
                    view=model_definition_interface.VIEW_FULL,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.GetNamespaceModelOperation,
            request=model_interface.GetNamespaceModelOperationRequest(
                namespace_id=namespace_id,
                model_id=model_id,
                version=version,
                view=model_definition_interface.VIEW_FULL,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def get_namespace_latest_model_operation(
        self,
        namespace_id: str,
        model_id: str,
        async_enabled: bool = False,
    ) -> model_interface.GetNamespaceLatestModelOperationResponse:

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.GetNamespaceLatestModelOperation,
                request=model_interface.GetNamespaceLatestModelOperationRequest(
                    namespace_id=namespace_id,
                    model_id=model_id,
                    view=model_definition_interface.VIEW_FULL,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.GetNamespaceLatestModelOperation,
            request=model_interface.GetNamespaceLatestModelOperationRequest(
                namespace_id=namespace_id,
                model_id=model_id,
                view=model_definition_interface.VIEW_FULL,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def get_model_operation(
        self,
        operation_id: str,
        async_enabled: bool = False,
    ) -> model_interface.GetModelOperationResponse:

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.GetModelOperation,
                request=model_interface.GetModelOperationRequest(
                    operation_id=operation_id,
                    view=model_definition_interface.VIEW_FULL,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.GetModelOperation,
            request=model_interface.GetModelOperationRequest(
                operation_id=operation_id,
                view=model_definition_interface.VIEW_FULL,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def delete_model(
        self,
        namespace_id: str,
        model_id: str,
        async_enabled: bool = False,
    ) -> model_interface.DeleteNamespaceModelResponse:

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.DeleteNamespaceModel,
                request=model_interface.DeleteNamespaceModelRequest(
                    namespace_id=namespace_id,
                    model_id=model_id,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.DeleteNamespaceModel,
            request=model_interface.DeleteNamespaceModelRequest(
                namespace_id=namespace_id,
                model_id=model_id,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def rename_model(
        self,
        namespace_id: str,
        model_id: str,
        new_model_id: str,
        async_enabled: bool = False,
    ) -> model_interface.RenameNamespaceModelResponse:

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.RenameNamespaceModel,
                request=model_interface.RenameNamespaceModelRequest(
                    namespace_id=namespace_id,
                    model_id=model_id,
                    new_model_id=new_model_id,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.RenameNamespaceModel,
            request=model_interface.RenameNamespaceModelRequest(
                namespace_id=namespace_id,
                model_id=model_id,
                new_model_id=new_model_id,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def get_model(
        self,
        namespace_id: str,
        model_id: str,
        async_enabled: bool = False,
    ) -> model_interface.GetNamespaceModelResponse:

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.GetNamespaceModel,
                request=model_interface.GetNamespaceModelRequest(
                    namespace_id=namespace_id,
                    model_id=model_id,
                    view=model_definition_interface.VIEW_FULL,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.GetNamespaceModel,
            request=model_interface.GetNamespaceModelRequest(
                namespace_id=namespace_id,
                model_id=model_id,
                view=model_definition_interface.VIEW_FULL,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def update_model(
        self,
        namespace_id: str,
        model_id: str,
        description: str,
        documentation_url: str,
        hardware: str,
        model_license: str = "",
        is_public: bool = True,
        async_enabled: bool = False,
    ) -> model_interface.UpdateNamespaceModelResponse:

        model = model_interface.Model(
            name=f"namespaces/{namespace_id}/models/{model_id}",
            description=description,
            documentation_url=documentation_url,
            hardware=hardware,
            license=model_license,
            visibility=(
                model_interface.Model.VISIBILITY_PUBLIC
                if is_public
                else model_interface.Model.VISIBILITY_PRIVATE
            ),
        )
        update_mask = field_mask_pb2.FieldMask()
        update_mask.paths.extend(
            [
                "description",
                "documentation_url",
                "hardware",
                "license",
                "visibility",
            ]
        )

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.UpdateNamespaceModel,
                request=model_interface.UpdateNamespaceModelRequest(
                    namespace_id=namespace_id,
                    model_id=model_id,
                    model=model,
                    update_mask=update_mask,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.UpdateNamespaceModel,
            request=model_interface.UpdateNamespaceModelRequest(
                namespace_id=namespace_id,
                model_id=model_id,
                model=model,
                update_mask=update_mask,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def lookup_model(
        self,
        model_uid: str,
        async_enabled: bool = False,
    ) -> model_interface.LookUpModelResponse:

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.LookUpModel,
                request=model_interface.LookUpModelRequest(
                    permalink=f"models/{model_uid}"
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.LookUpModel,
            request=model_interface.LookUpModelRequest(permalink=f"models/{model_uid}"),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def list_models(
        self,
        namespace_id: str,
        is_public: bool = True,
        next_page_token: str = "",
        total_size: int = 10,
        show_deleted: bool = False,
        public=False,
        filter_str: str = "",
        order_by: str = "",
        async_enabled: bool = False,
    ) -> model_interface.ListNamespaceModelsResponse:

        visibility = (
            model_interface.Model.VISIBILITY_PUBLIC
            if is_public
            else model_interface.Model.VISIBILITY_PRIVATE
        )

        if async_enabled:
            if public:
                method = self.host.async_client.ListModels
                return RequestFactory(
                    method=method,
                    request=model_interface.ListModelsRequest(
                        page_size=total_size,
                        page_token=next_page_token,
                        show_deleted=show_deleted,
                        view=model_definition_interface.VIEW_FULL,
                        filter=filter_str,
                        visibility=visibility,
                        order_by=order_by,
                    ),
                    metadata=self.host.metadata + self.metadata,
                ).send_async()
            method = self.host.async_client.ListNamespaceModels
            return RequestFactory(
                method=method,
                request=model_interface.ListNamespaceModelsRequest(
                    namespace_id=namespace_id,
                    page_size=total_size,
                    page_token=next_page_token,
                    show_deleted=show_deleted,
                    view=model_definition_interface.VIEW_FULL,
                    filter=filter_str,
                    visibility=visibility,
                    order_by=order_by,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()
        if public:
            method = self.host.client.ListModels
            return RequestFactory(
                method=method,
                request=model_interface.ListModelsRequest(
                    page_size=total_size,
                    page_token=next_page_token,
                    show_deleted=show_deleted,
                    view=model_definition_interface.VIEW_FULL,
                    filter=filter_str,
                    visibility=visibility,
                    order_by=order_by,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_sync()
        method = self.host.client.ListNamespaceModels
        return RequestFactory(
            method=method,
            request=model_interface.ListNamespaceModelsRequest(
                namespace_id=namespace_id,
                page_size=total_size,
                page_token=next_page_token,
                show_deleted=show_deleted,
                view=model_definition_interface.VIEW_FULL,
                filter=filter_str,
                visibility=visibility,
                order_by=order_by,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def list_model_definitions(
        self,
        page_size: int = 10,
        page_token: str = "",
        async_enabled: bool = False,
    ) -> model_definition_interface.ListModelDefinitionsResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.ListModelDefinitions,
                request=model_definition_interface.ListModelDefinitionsRequest(
                    page_size=page_size,
                    page_token=page_token,
                    view=model_definition_interface.VIEW_FULL,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.ListModelDefinitions,
            request=model_definition_interface.ListModelDefinitionsRequest(
                page_size=page_size,
                page_token=page_token,
                view=model_definition_interface.VIEW_FULL,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def list_available_regions(
        self,
        async_enabled: bool = False,
    ) -> model_interface.ListAvailableRegionsResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.ListAvailableRegions,
                request=model_interface.ListAvailableRegionsRequest(),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.ListAvailableRegions,
            request=model_interface.ListAvailableRegionsRequest(),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def get_model_definition(
        self,
        model_definition_id: str,
        async_enabled: bool = False,
    ) -> model_definition_interface.GetModelDefinitionResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.GetModelDefinition,
                request=model_definition_interface.GetModelDefinitionRequest(
                    view=model_definition_interface.VIEW_FULL,
                    model_definition_id=model_definition_id,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.GetModelDefinition,
            request=model_definition_interface.GetModelDefinitionRequest(
                view=model_definition_interface.VIEW_FULL,
                model_definition_id=model_definition_id,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def get_operation(
        self,
        operation_id: str,
        async_enabled: bool = False,
    ) -> model_interface.GetModelOperationResponse:

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.GetModelOperation,
                request=model_interface.GetModelOperationRequest(
                    operation_id=operation_id,
                    view=model_definition_interface.VIEW_FULL,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.GetModelOperation,
            request=model_interface.GetModelOperationRequest(
                operation_id=operation_id,
                view=model_definition_interface.VIEW_FULL,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def get_latest_model_operation(
        self,
        namespace_id: str,
        model_id: str,
        async_enabled: bool = False,
    ) -> model_interface.GetNamespaceLatestModelOperationResponse:

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.GetNamespaceLatestModelOperation,
                request=model_interface.GetNamespaceLatestModelOperationRequest(
                    namespace_id=namespace_id,
                    model_id=model_id,
                    view=model_definition_interface.VIEW_FULL,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.GetNamespaceLatestModelOperation,
            request=model_interface.GetNamespaceLatestModelOperationRequest(
                namespace_id=namespace_id,
                model_id=model_id,
                view=model_definition_interface.VIEW_FULL,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def list_model_versions(
        self,
        namespace_id: str,
        page: int,
        model_id: str,
        page_size: int = 10,
        async_enabled: bool = False,
    ) -> model_interface.ListNamespaceModelVersionsResponse:

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.ListNamespaceModelVersions,
                request=model_interface.ListNamespaceModelVersionsRequest(
                    namespace_id=namespace_id,
                    model_id=model_id,
                    page_size=page_size,
                    page=page,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.ListNamespaceModelVersions,
            request=model_interface.ListNamespaceModelVersionsRequest(
                namespace_id=namespace_id,
                model_id=model_id,
                page_size=page_size,
                page=page,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def delete_model_version(
        self,
        namespace_id: str,
        model_id: str,
        version: str,
        async_enabled: bool = False,
    ) -> model_interface.DeleteNamespaceModelVersionResponse:

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.DeleteNamespaceModelVersion,
                request=model_interface.DeleteNamespaceModelVersionRequest(
                    namespace_id=namespace_id,
                    model_id=model_id,
                    version=version,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.DeleteNamespaceModelVersion,
            request=model_interface.DeleteNamespaceModelVersionRequest(
                namespace_id=namespace_id,
                model_id=model_id,
                version=version,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def list_model_runs(
        self,
        namespace_id: str,
        model_id: str,
        page_size: int = 10,
        page: int = 0,
        order_by: str = "",
        filter_str: str = "",
        async_enabled: bool = False,
    ) -> model_interface.ListModelRunsResponse:

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.ListModelRuns,
                request=model_interface.ListModelRunsRequest(
                    namespace_id=namespace_id,
                    model_id=model_id,
                    page_size=page_size,
                    page=page,
                    order_by=order_by,
                    filter=filter_str,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.ListModelRuns,
            request=model_interface.ListModelRunsRequest(
                namespace_id=namespace_id,
                model_id=model_id,
                page_size=page_size,
                page=page,
                order_by=order_by,
                filter=filter_str,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def list_model_runs_by_credit_owner(
        self,
        start: datetime,
        stop: datetime,
        page_size: int = 10,
        page: int = 0,
        order_by: str = "",
        filter_str: str = "",
        async_enabled: bool = False,
    ) -> model_interface.ListModelRunsByCreditOwnerResponse:
        start_timestamp = timestamp_pb2.Timestamp()
        start_timestamp.FromDatetime(start)
        stop_timestamp = timestamp_pb2.Timestamp()
        stop_timestamp.FromDatetime(stop)

        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.ListModelRunsByCreditOwner,
                request=model_interface.ListModelRunsByCreditOwnerRequest(
                    start=start_timestamp,
                    stop=stop_timestamp,
                    page_size=page_size,
                    page=page,
                    order_by=order_by,
                    filter=filter_str,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.ListModelRunsByCreditOwner,
            request=model_interface.ListModelRunsByCreditOwnerRequest(
                start=start_timestamp,
                stop=stop_timestamp,
                page_size=page_size,
                page=page,
                order_by=order_by,
                filter=filter_str,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ray.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tray.proto\x12\x06ray.v1\x1a\x1cgoogle/protobuf/struct.proto\";\n\x0b\x43\x61llRequest\x12,\n\x0btask_inputs\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct\"=\n\x0c\x43\x61llResponse\x12-\n\x0ctask_outputs\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct2C\n\nRayService\x12\x35\n\x08__call__\x12\x13.ray.v1.CallRequest\x1a\x14.ray.v1.CallResponseB\rZ\x0b./rayserverb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ray_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\013./rayserver'
  _globals['_CALLREQUEST']._serialized_start=51
  _globals['_CALLREQUEST']._serialized_end=110
  _globals['_CALLRESPONSE']._serialized_start=112
  _globals['_CALLRESPONSE']._serialized_end=173
  _globals['_RAYSERVICE']._serialized_start=175
  _globals['_RAYSERVICE']._serialized_end=242
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: app/app/v1alpha/app.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from app.app.v1alpha import conversation_pb2 as app_dot_app_dot_v1alpha_dot_conversation__pb2
from common.healthcheck.v1beta import healthcheck_pb2 as common_dot_healthcheck_dot_v1beta_dot_healthcheck__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x61pp/app/v1alpha/app.proto\x12\x0f\x61pp.app.v1alpha\x1a\"app/app/v1alpha/conversation.proto\x1a+common/healthcheck/v1beta/healthcheck.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x95\x01\n\x0fLivenessRequest\x12i\n\x14health_check_request\x18\x01 \x01(\x0b\x32-.common.healthcheck.v1beta.HealthCheckRequestB\x03\xe0\x41\x01H\x00R\x12healthCheckRequest\x88\x01\x01\x42\x17\n\x15_health_check_request\"{\n\x10LivenessResponse\x12g\n\x15health_check_response\x18\x01 \x01(\x0b\x32..common.healthcheck.v1beta.HealthCheckResponseB\x03\xe0\x41\x03R\x13healthCheckResponse\"\x96\x01\n\x10ReadinessRequest\x12i\n\x14health_check_request\x18\x01 \x01(\x0b\x32-.common.healthcheck.v1beta.HealthCheckRequestB\x03\xe0\x41\x01H\x00R\x12healthCheckRequest\x88\x01\x01\x42\x17\n\x15_health_check_request\"|\n\x11ReadinessResponse\x12g\n\x15health_check_response\x18\x01 \x01(\x0b\x32..common.healthcheck.v1beta.HealthCheckResponseB\x03\xe0\x41\x03R\x13healthCheckResponse\"\xeb\x03\n\x03\x41pp\x12\x1a\n\x06\x61pp_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x05\x61ppId\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x03\xe0\x41\x01R\x0b\x64\x65scription\x12@\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\x12 \n\towner_uid\x18\x05 \x01(\tB\x03\xe0\x41\x03R\x08ownerUid\x12\x17\n\x04tags\x18\x06 \x03(\tB\x03\xe0\x41\x01R\x04tags\x12X\n\x10\x61i_assistant_app\x18\x07 \x01(\x0b\x32\'.app.app.v1alpha.AIAssistantAppMetadataB\x03\xe0\x41\x03H\x00R\x0e\x61iAssistantApp\x12\x38\n\x08\x61pp_type\x18\x08 \x01(\x0e\x32\x18.app.app.v1alpha.AppTypeB\x03\xe0\x41\x03R\x07\x61ppType\x12\x1c\n\x07\x61pp_uid\x18\t \x01(\tB\x03\xe0\x41\x03R\x06\x61ppUid\x12$\n\x0b\x63reator_uid\x18\n \x01(\tB\x03\xe0\x41\x03R\ncreatorUidB\n\n\x08metadata\"X\n\x16\x41IAssistantAppMetadata\x12$\n\x0b\x63\x61talog_uid\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncatalogUid\x12\x18\n\x05top_k\x18\x02 \x01(\x05\x42\x03\xe0\x41\x02R\x04topK\"\x8f\x01\n\x10\x43reateAppRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x13\n\x02id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x02id\x12%\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x03\xe0\x41\x01R\x0b\x64\x65scription\x12\x17\n\x04tags\x18\x04 \x03(\tB\x03\xe0\x41\x01R\x04tags\"@\n\x11\x43reateAppResponse\x12+\n\x03\x61pp\x18\x01 \x01(\x0b\x32\x14.app.app.v1alpha.AppB\x03\xe0\x41\x03R\x03\x61pp\"9\n\x0fListAppsRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\"A\n\x10ListAppsResponse\x12-\n\x04\x61pps\x18\x01 \x03(\x0b\x32\x14.app.app.v1alpha.AppB\x03\xe0\x41\x03R\x04\x61pps\"\xd7\x02\n\x10UpdateAppRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1a\n\x06\x61pp_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x05\x61ppId\x12!\n\nnew_app_id\x18\x03 \x01(\tB\x03\xe0\x41\x01R\x08newAppId\x12,\n\x0fnew_description\x18\x04 \x01(\tB\x03\xe0\x41\x01R\x0enewDescription\x12\x1e\n\x08new_tags\x18\x05 \x03(\tB\x03\xe0\x41\x01R\x07newTags\x12L\n!last_ai_assistant_app_catalog_uid\x18\x06 \x01(\tB\x03\xe0\x41\x01R\x1clastAiAssistantAppCatalogUid\x12@\n\x1blast_ai_assistant_app_top_k\x18\x07 \x01(\x05\x42\x03\xe0\x41\x01R\x16lastAiAssistantAppTopK\"@\n\x11UpdateAppResponse\x12+\n\x03\x61pp\x18\x01 \x01(\x0b\x32\x14.app.app.v1alpha.AppB\x03\xe0\x41\x03R\x03\x61pp\"V\n\x10\x44\x65leteAppRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1a\n\x06\x61pp_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x05\x61ppId\"\x13\n\x11\x44\x65leteAppResponse\"j\n$RestartPlaygroundConversationRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1a\n\x06\x61pp_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x05\x61ppId\"o\n%RestartPlaygroundConversationResponse\x12\x46\n\x0c\x63onversation\x18\x01 \x01(\x0b\x32\x1d.app.app.v1alpha.ConversationB\x03\xe0\x41\x03R\x0c\x63onversation\"f\n GetPlaygroundConversationRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1a\n\x06\x61pp_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x05\x61ppId\"k\n!GetPlaygroundConversationResponse\x12\x46\n\x0c\x63onversation\x18\x01 \x01(\x0b\x32\x1d.app.app.v1alpha.ConversationB\x03\xe0\x41\x03R\x0c\x63onversation*>\n\x07\x41ppType\x12\x18\n\x14\x41PP_TYPE_UNSPECIFIED\x10\x00\x12\x19\n\x15\x41PP_TYPE_AI_ASSISTANT\x10\x01\x42\xbb\x01\n\x13\x63om.app.app.v1alphaB\x08\x41ppProtoP\x01Z<github.com/instill-ai/protogen-go/app/app/v1alpha;appv1alpha\xa2\x02\x03\x41\x41X\xaa\x02\x0f\x41pp.App.V1alpha\xca\x02\x0f\x41pp\\App\\V1alpha\xe2\x02\x1b\x41pp\\App\\V1alpha\\GPBMetadata\xea\x02\x11\x41pp::App::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'app.app.v1alpha.app_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023com.app.app.v1alphaB\010AppProtoP\001Z<github.com/instill-ai/protogen-go/app/app/v1alpha;appv1alpha\242\002\003AAX\252\002\017App.App.V1alpha\312\002\017App\\App\\V1alpha\342\002\033App\\App\\V1alpha\\GPBMetadata\352\002\021App::App::V1alpha'
  _LIVENESSREQUEST.fields_by_name['health_check_request']._options = None
  _LIVENESSREQUEST.fields_by_name['health_check_request']._serialized_options = b'\340A\001'
  _LIVENESSRESPONSE.fields_by_name['health_check_response']._options = None
  _LIVENESSRESPONSE.fields_by_name['health_check_response']._serialized_options = b'\340A\003'
  _READINESSREQUEST.fields_by_name['health_check_request']._options = None
  _READINESSREQUEST.fields_by_name['health_check_request']._serialized_options = b'\340A\001'
  _READINESSRESPONSE.fields_by_name['health_check_response']._options = None
  _READINESSRESPONSE.fields_by_name['health_check_response']._serialized_options = b'\340A\003'
  _APP.fields_by_name['app_id']._options = None
  _APP.fields_by_name['app_id']._serialized_options = b'\340A\002'
  _APP.fields_by_name['description']._options = None
  _APP.fields_by_name['description']._serialized_options = b'\340A\001'
  _APP.fields_by_name['create_time']._options = None
  _APP.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _APP.fields_by_name['update_time']._options = None
  _APP.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _APP.fields_by_name['owner_uid']._options = None
  _APP.fields_by_name['owner_uid']._serialized_options = b'\340A\003'
  _APP.fields_by_name['tags']._options = None
  _APP.fields_by_name['tags']._serialized_options = b'\340A\001'
  _APP.fields_by_name['ai_assistant_app']._options = None
  _APP.fields_by_name['ai_assistant_app']._serialized_options = b'\340A\003'
  _APP.fields_by_name['app_type']._options = None
  _APP.fields_by_name['app_type']._serialized_options = b'\340A\003'
  _APP.fields_by_name['app_uid']._options = None
  _APP.fields_by_name['app_uid']._serialized_options = b'\340A\003'
  _APP.fields_by_name['creator_uid']._options = None
  _APP.fields_by_name['creator_uid']._serialized_options = b'\340A\003'
  _AIASSISTANTAPPMETADATA.fields_by_name['catalog_uid']._options = None
  _AIASSISTANTAPPMETADATA.fields_by_name['catalog_uid']._serialized_options = b'\340A\002'
  _AIASSISTANTAPPMETADATA.fields_by_name['top_k']._options = None
  _AIASSISTANTAPPMETADATA.fields_by_name['top_k']._serialized_options = b'\340A\002'
  _CREATEAPPREQUEST.fields_by_name['namespace_id']._options = None
  _CREATEAPPREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _CREATEAPPREQUEST.fields_by_name['id']._options = None
  _CREATEAPPREQUEST.fields_by_name['id']._serialized_options = b'\340A\002'
  _CREATEAPPREQUEST.fields_by_name['description']._options = None
  _CREATEAPPREQUEST.fields_by_name['description']._serialized_options = b'\340A\001'
  _CREATEAPPREQUEST.fields_by_name['tags']._options = None
  _CREATEAPPREQUEST.fields_by_name['tags']._serialized_options = b'\340A\001'
  _CREATEAPPRESPONSE.fields_by_name['app']._options = None
  _CREATEAPPRESPONSE.fields_by_name['app']._serialized_options = b'\340A\003'
  _LISTAPPSREQUEST.fields_by_name['namespace_id']._options = None
  _LISTAPPSREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTAPPSRESPONSE.fields_by_name['apps']._options = None
  _LISTAPPSRESPONSE.fields_by_name['apps']._serialized_options = b'\340A\003'
  _UPDATEAPPREQUEST.fields_by_name['namespace_id']._options = None
  _UPDATEAPPREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _UPDATEAPPREQUEST.fields_by_name['app_id']._options = None
  _UPDATEAPPREQUEST.fields_by_name['app_id']._serialized_options = b'\340A\002'
  _UPDATEAPPREQUEST.fields_by_name['new_app_id']._options = None
  _UPDATEAPPREQUEST.fields_by_name['new_app_id']._serialized_options = b'\340A\001'
  _UPDATEAPPREQUEST.fields_by_name['new_description']._options = None
  _UPDATEAPPREQUEST.fields_by_name['new_description']._serialized_options = b'\340A\001'
  _UPDATEAPPREQUEST.fields_by_name['new_tags']._options = None
  _UPDATEAPPREQUEST.fields_by_name['new_tags']._serialized_options = b'\340A\001'
  _UPDATEAPPREQUEST.fields_by_name['last_ai_assistant_app_catalog_uid']._options = None
  _UPDATEAPPREQUEST.fields_by_name['last_ai_assistant_app_catalog_uid']._serialized_options = b'\340A\001'
  _UPDATEAPPREQUEST.fields_by_name['last_ai_assistant_app_top_k']._options = None
  _UPDATEAPPREQUEST.fields_by_name['last_ai_assistant_app_top_k']._serialized_options = b'\340A\001'
  _UPDATEAPPRESPONSE.fields_by_name['app']._options = None
  _UPDATEAPPRESPONSE.fields_by_name['app']._serialized_options = b'\340A\003'
  _DELETEAPPREQUEST.fields_by_name['namespace_id']._options = None
  _DELETEAPPREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _DELETEAPPREQUEST.fields_by_name['app_id']._options = None
  _DELETEAPPREQUEST.fields_by_name['app_id']._serialized_options = b'\340A\002'
  _RESTARTPLAYGROUNDCONVERSATIONREQUEST.fields_by_name['namespace_id']._options = None
  _RESTARTPLAYGROUNDCONVERSATIONREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _RESTARTPLAYGROUNDCONVERSATIONREQUEST.fields_by_name['app_id']._options = None
  _RESTARTPLAYGROUNDCONVERSATIONREQUEST.fields_by_name['app_id']._serialized_options = b'\340A\002'
  _RESTARTPLAYGROUNDCONVERSATIONRESPONSE.fields_by_name['conversation']._options = None
  _RESTARTPLAYGROUNDCONVERSATIONRESPONSE.fields_by_name['conversation']._serialized_options = b'\340A\003'
  _GETPLAYGROUNDCONVERSATIONREQUEST.fields_by_name['namespace_id']._options = None
  _GETPLAYGROUNDCONVERSATIONREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _GETPLAYGROUNDCONVERSATIONREQUEST.fields_by_name['app_id']._options = None
  _GETPLAYGROUNDCONVERSATIONREQUEST.fields_by_name['app_id']._serialized_options = b'\340A\002'
  _GETPLAYGROUNDCONVERSATIONRESPONSE.fields_by_name['conversation']._options = None
  _GETPLAYGROUNDCONVERSATIONRESPONSE.fields_by_name['conversation']._serialized_options = b'\340A\003'
  _globals['_APPTYPE']._serialized_start=2626
  _globals['_APPTYPE']._serialized_end=2688
  _globals['_LIVENESSREQUEST']._serialized_start=194
  _globals['_LIVENESSREQUEST']._serialized_end=343
  _globals['_LIVENESSRESPONSE']._serialized_start=345
  _globals['_LIVENESSRESPONSE']._serialized_end=468
  _globals['_READINESSREQUEST']._serialized_start=471
  _globals['_READINESSREQUEST']._serialized_end=621
  _globals['_READINESSRESPONSE']._serialized_start=623
  _globals['_READINESSRESPONSE']._serialized_end=747
  _globals['_APP']._serialized_start=750
  _globals['_APP']._serialized_end=1241
  _globals['_AIASSISTANTAPPMETADATA']._serialized_start=1243
  _globals['_AIASSISTANTAPPMETADATA']._serialized_end=1331
  _globals['_CREATEAPPREQUEST']._serialized_start=1334
  _globals['_CREATEAPPREQUEST']._serialized_end=1477
  _globals['_CREATEAPPRESPONSE']._serialized_start=1479
  _globals['_CREATEAPPRESPONSE']._serialized_end=1543
  _globals['_LISTAPPSREQUEST']._serialized_start=1545
  _globals['_LISTAPPSREQUEST']._serialized_end=1602
  _globals['_LISTAPPSRESPONSE']._serialized_start=1604
  _globals['_LISTAPPSRESPONSE']._serialized_end=1669
  _globals['_UPDATEAPPREQUEST']._serialized_start=1672
  _globals['_UPDATEAPPREQUEST']._serialized_end=2015
  _globals['_UPDATEAPPRESPONSE']._serialized_start=2017
  _globals['_UPDATEAPPRESPONSE']._serialized_end=2081
  _globals['_DELETEAPPREQUEST']._serialized_start=2083
  _globals['_DELETEAPPREQUEST']._serialized_end=2169
  _globals['_DELETEAPPRESPONSE']._serialized_start=2171
  _globals['_DELETEAPPRESPONSE']._serialized_end=2190
  _globals['_RESTARTPLAYGROUNDCONVERSATIONREQUEST']._serialized_start=2192
  _globals['_RESTARTPLAYGROUNDCONVERSATIONREQUEST']._serialized_end=2298
  _globals['_RESTARTPLAYGROUNDCONVERSATIONRESPONSE']._serialized_start=2300
  _globals['_RESTARTPLAYGROUNDCONVERSATIONRESPONSE']._serialized_end=2411
  _globals['_GETPLAYGROUNDCONVERSATIONREQUEST']._serialized_start=2413
  _globals['_GETPLAYGROUNDCONVERSATIONREQUEST']._serialized_end=2515
  _globals['_GETPLAYGROUNDCONVERSATIONRESPONSE']._serialized_start=2517
  _globals['_GETPLAYGROUNDCONVERSATIONRESPONSE']._serialized_end=2624
# @@protoc_insertion_point(module_scope)
